:mod:`euphorie.client.utils`
============================

.. module:: euphorie.client.utils

.. autoclass:: WebHelpers
   :members:

.. autofunction:: HasText

.. autofunction:: setLanguage

.. autofunction:: RelativePath

.. autofunction:: MatchColour(colour, low_l=0.2, high_l=0.65)

.. autofunction:: IsBright

